{-| Module      : Graph.Clustering.Types
Description : 
Copyright   : (c) CNRS, Alexandre Delanoë
License     : AGPL (MIT) + CECILL (CEA/CNRS/INRIA)
Maintainer  : alexandre+dev@delanoe.org
Stability   : experimental
Portability : POSIX

Generic Types for Clustering

-}


module Graph.BAC.Clustering.Types
  where

import Data.Set (Set)
import Graph.Types (Dict)
import Graph.Lib.FGL
import qualified Data.IntMap                       as Dict
import qualified Data.Graph.Inductive              as DGI

-- | Where main Types are defined as
data Similarity = Conf | Mod

type Length      = Int

data ClusteringMode = Part | Over | Both
  deriving (Show, Eq)

data Clustering a = ClusteringIs { parts :: !(Dict (Set a))
                                 , index :: !(Dict Int)
                                 , score :: !(Double)
                                 , mode  :: !ClusteringMode
                                 }
                  | ClusteringLight { cl_modules :: Set (Set a)
                                    , cl_score   :: Double
                                    , cl_mode    :: !ClusteringMode
                                    }
                  | Clusterings { strict :: !(StrictClustering   a)
                                , over   :: !(OverlapsClustering a)
                                }
  deriving (Show, Eq)

type StrictClustering   a = Clustering a
type OverlapsClustering a = Clustering a

type IsReflexive = Bool
type NeighborsFilter a b = DGI.Gr a b -> Node -> [Node]
type RmEdge      = Bool


