module Graph.Dataset.Jouer
  (graph_jouer, graph_jouer_clustering', graph_jouer_clustering)
  where

import Data.Maybe (catMaybes, fromMaybe)
import Data.Text (Text)
import Graph.BAC.Clustering
import Graph.BAC.Clustering.Types
import Graph.Lib.FGL (mkGraphUfromEdges, Node)
import Graph.Tools.Import (GraphData(..))
import Graph.Types
import qualified Data.IntMap as Dict
import qualified Data.Set as Set
import Data.Graph.Inductive (mkGraph, LNode, LEdge)

graph_jouer :: GraphData
graph_jouer = LabelledGraph $ mkGraph nodes_label edges

withLabel :: (Node -> [Text])
                       -> Clustering Node
                       -> Clustering [Text]
withLabel f (ClusteringLight mods s m) =
  ClusteringLight (Set.map (Set.map f) mods) s m

addLabel :: Monoid a => Dict a -> Node -> a
addLabel d n = fromMaybe mempty (Dict.lookup n d)


graph_jouer_clustering' :: Clustering [Text]
graph_jouer_clustering' = withLabel labels graph_jouer_clustering
  where
    labels = addLabel (Dict.fromAscList nodes_label)


graph_jouer_clustering :: Clustering Node
graph_jouer_clustering = ClusteringLight {cl_modules = Set.fromList [Set.fromList [0,4,9,17,23,25,26,38,43,53,59,79],Set.fromList [1,5,47,49,76],Set.fromList [2,15,20,21,33,34,35,36,39,42,50,75,80],Set.fromList [3,18,28,29,37,45,51,54,67,68,77],Set.fromList [6,11,12,19,30,41,44,48,58,73,78],Set.fromList [7,8,10,27,46,52,57,60,63,64,65,74],Set.fromList [13,14,16,22,24,31,32,40,55,56,69,70],Set.fromList [61,62],Set.fromList [66,71,72]], cl_score = 191.52839713370616, cl_mode = Part}

nodes_label :: [LNode [Text]]
nodes_label = [(0,["abuser-c2"]),(1,["affecter-c1"]),(2,["agir-1-6"]),(3,["agiter-c5"]),(4,["amuser-c2"]),(5,["attaquer-1"]),(6,["aventurer-c4"]),(7,["badiner-c3"]),(8,["batifoler-c3"]),(9,["berner-c2"]),(10,["blaguer-c3"]),(11,["boursicoter-c4"]),(12,["compromettre-c4"]),(13,["contrefaire-c1"]),(14,["copier-c1"]),(15,["cr\233er-c1"]),(16,["donner-1-4-5"]),(17,["duper-c2"]),(18,["enlever-1-5"]),(19,["exposer-4-5"]),(20,["ex\233cuter-c6"]),(21,["faire-c6-1-2"]),(22,["feindre-1-2"]),(23,["feinter-c2"]),(24,["figurer-c1"]),(25,["flamber-c2"]),(26,["flouer-c2"]),(27,["fol\226trer-c3"]),(28,["fonctionner-c5"]),(29,["gratter-c5"]),(30,["hasarder-c4"]),(31,["imiter-c1"]),(32,["incarner-c1"]),(33,["influer-1-5"]),(34,["interpr\233ter-1"]),(35,["intervenir-1"]),(36,["manier-c6"]),(37,["marcher-c5"]),(38,["mentir-2-3"]),(39,["mettre en sc\232ne-c1"]),(40,["mimer-c1"]),(41,["miser-c4"]),(42,["monter-c1"]),(43,["mystifier-c2"]),(44,["parier-c4"]),(45,["passer-c5"]),(46,["plaisanter-c3"]),(47,["plastronner-c1"]),(48,["ponter-c4"]),(49,["poser-c1"]),(50,["pratiquer-c6"]),(51,["racler-5"]),(52,["railler-c3"]),(53,["refaire-c2-1"]),(54,["remuer-c5"]),(55,["reproduire-c1"]),(56,["repr\233senter-c1"]),(57,["rire-c3"]),(58,["risquer-c4"]),(59,["rouler-2-5"]),(60,["s'amuser-c3"]),(61,["s'entra\238ner-c6"]),(62,["s'exercer-c6"]),(63,["s'\233battre-c3"]),(64,["s'\233brouer-c3"]),(65,["se divertir-c3"]),(66,["se faire entendre-c7"]),(67,["se mouvoir-c5"]),(68,["secouer-c5"]),(69,["simuler-c1"]),(70,["singer-c1"]),(71,["sonner-c7"]),(72,["souffler-c7"]),(73,["sp\233culer-c4"]),(74,["taquiner-c3"]),(75,["tenir-c6"]),(76,["toucher-1-5-6"]),(77,["tourner-c5"]),(78,["tripoter-4"]),(79,["tromper-c2"]),(80,["user-c6"])]


edges :: [(Node,Node,Double)]
edges = [(0,2,1.0),(0,4,1.0),(0,9,1.0),(0,17,1.0),(0,22,1.0),(0,38,1.0),(0,43,1.0),(0,53,1.0),(0,59,1.0),(0,60,1.0),(0,79,1.0),(1,5,1.0),(1,13,1.0),(1,22,1.0),(1,47,1.0),(1,49,1.0),(1,69,1.0),(1,70,1.0),(1,76,1.0),(2,20,1.0),(2,21,1.0),(2,28,1.0),(2,33,1.0),(2,35,1.0),(2,56,1.0),(2,80,1.0),(3,36,1.0),(3,54,1.0),(3,68,1.0),(4,9,1.0),(4,17,1.0),(4,26,1.0),(4,43,1.0),(4,57,1.0),(4,79,1.0),(5,76,1.0),(6,12,1.0),(6,19,1.0),(6,30,1.0),(6,58,1.0),(7,10,1.0),(7,27,1.0),(7,46,1.0),(7,52,1.0),(7,57,1.0),(7,60,1.0),(7,74,1.0),(8,27,1.0),(8,46,1.0),(8,60,1.0),(8,63,1.0),(9,17,1.0),(9,26,1.0),(9,43,1.0),(9,52,1.0),(9,53,1.0),(9,59,1.0),(9,79,1.0),(10,38,1.0),(10,46,1.0),(10,52,1.0),(10,57,1.0),(10,74,1.0),(11,30,1.0),(11,41,1.0),(11,73,1.0),(11,78,1.0),(12,19,1.0),(12,30,1.0),(12,58,1.0),(13,14,1.0),(13,21,1.0),(13,22,1.0),(13,31,1.0),(13,40,1.0),(13,55,1.0),(13,69,1.0),(13,70,1.0),(14,31,1.0),(14,40,1.0),(14,55,1.0),(14,56,1.0),(14,69,1.0),(14,70,1.0),(15,21,1.0),(15,34,1.0),(15,42,1.0),(16,19,1.0),(16,21,1.0),(16,35,1.0),(16,45,1.0),(16,56,1.0),(17,21,1.0),(17,26,1.0),(17,43,1.0),(17,53,1.0),(17,59,1.0),(17,79,1.0),(18,29,1.0),(18,42,1.0),(18,51,1.0),(18,72,1.0),(19,30,1.0),(19,56,1.0),(19,58,1.0),(19,77,1.0),(20,21,1.0),(20,34,1.0),(20,50,1.0),(20,75,1.0),(21,24,1.0),(21,31,1.0),(21,34,1.0),(21,42,1.0),(21,50,1.0),(21,53,1.0),(21,55,1.0),(21,56,1.0),(21,69,1.0),(21,70,1.0),(21,75,1.0),(21,80,1.0),(22,31,1.0),(22,38,1.0),(22,69,1.0),(22,79,1.0),(23,43,1.0),(23,59,1.0),(23,79,1.0),(24,31,1.0),(24,32,1.0),(24,55,1.0),(24,56,1.0),(25,53,1.0),(26,43,1.0),(26,53,1.0),(26,59,1.0),(26,79,1.0),(27,46,1.0),(27,60,1.0),(27,63,1.0),(27,64,1.0),(28,37,1.0),(28,54,1.0),(28,67,1.0),(28,77,1.0),(29,45,1.0),(29,51,1.0),(29,54,1.0),(30,58,1.0),(31,40,1.0),(31,55,1.0),(31,56,1.0),(31,69,1.0),(31,70,1.0),(32,34,1.0),(32,55,1.0),(32,56,1.0),(33,77,1.0),(34,56,1.0),(34,77,1.0),(36,50,1.0),(36,75,1.0),(36,76,1.0),(36,78,1.0),(36,80,1.0),(37,45,1.0),(37,59,1.0),(37,67,1.0),(37,77,1.0),(38,43,1.0),(38,46,1.0),(38,79,1.0),(39,42,1.0),(39,56,1.0),(40,55,1.0),(40,56,1.0),(40,69,1.0),(40,70,1.0),(41,44,1.0),(41,48,1.0),(41,58,1.0),(43,53,1.0),(43,59,1.0),(43,79,1.0),(44,48,1.0),(45,77,1.0),(46,52,1.0),(46,57,1.0),(46,60,1.0),(46,74,1.0),(47,49,1.0),(48,58,1.0),(49,69,1.0),(50,61,1.0),(50,75,1.0),(50,80,1.0),(52,57,1.0),(52,60,1.0),(53,55,1.0),(53,59,1.0),(53,79,1.0),(54,59,1.0),(54,67,1.0),(54,68,1.0),(54,76,1.0),(54,77,1.0),(55,56,1.0),(55,69,1.0),(55,70,1.0),(56,69,1.0),(57,60,1.0),(57,65,1.0),(59,67,1.0),(59,76,1.0),(59,77,1.0),(59,79,1.0),(60,63,1.0),(60,65,1.0),(60,74,1.0),(61,62,1.0),(63,64,1.0),(63,65,1.0),(64,72,1.0),(66,71,1.0),(69,70,1.0),(71,72,1.0),(73,78,1.0),(76,78,1.0)]

